Integer

Struct Integer 

pub struct Integer { /* private fields */ }
A TOML integer value.

This is a storage type that supports the full range of i128. Convert to a primitive with as_i128, as_i64, or as_u64, perform your arithmetic there, then convert back with From.

Implementations

Source

impl Integer

pub fn as_i128(&self) -> i128

Returns the value as an i128.

pub fn as_f64(&self) -> f64

Returns the value as an f64, which may be lossy for large integers.

pub fn as_i64(&self) -> Option<i64>

Returns the value as an i64, or None if it does not fit.

pub fn as_u64(&self) -> Option<u64>

Returns the value as a u64, or None if it does not fit.